Tokdash

Total Tokens
-
Total Cost
$-
Total Messages
-
Top Model
-
-

## Usage by Tool

Tokens

## Top Models by Cost

USD

## Tools Breakdown

Tool | Tokens | Cost
--- | --- | ---
Loading…

## Apps & Models Breakdown

Loading…

## Combined Models

Unified view across all apps and providers. Models with the same name are aggregated regardless of source.

Model | Input | Output | Cache | Total | Cost | Msgs
--- | --- | --- | --- | --- | --- | ---
Loading…

## Codex Sessions

Latest session plus sessions for the selected range.

Latest Session
Loading…
-
Input
-
Cache Read
-
-
Output
-
Total Tokens
-
Events
-
-

Session | Model | Input | Cache | Output | Total | Cost | Last updated
--- | --- | --- | --- | --- | --- | --- | ---
Loading…

## Claude Code Sessions

Latest session plus sessions for the selected range.

Latest Session
Loading…
-
Input
-
Cache Read
-
-
Output
-
Total Tokens
-
Events
-
-

Session | Model | Input | Cache | Output | Total | Cost | Last updated
--- | --- | --- | --- | --- | --- | --- | ---
Loading…

## OpenCode Sessions

Latest session plus sessions for the selected range.

Latest Session
Loading…
-
Input
-
Cache Read
-
-
Output
-
Total Tokens
-
Events
-
-

Session | Model | Input | Cache | Output | Total | Cost | Last updated
--- | --- | --- | --- | --- | --- | --- | ---
Loading…

## Combined Sessions

Cross-tool session view grouped by project for the selected range.

Latest Session
Loading…
-
Input
-
Cache Read
-
-
Output
-
Total Tokens
-
Events
-
-

Session | Tool | Model | Input | Cache | Output | Total | Cost | Last updated
--- | --- | --- | --- | --- | --- | --- | --- | ---
Loading…

Top Model (Cost)
Loading…
Total Tokens
Loading…
Sessions
Loading…
Streak
Loading…
Longest Streak
Loading…
Active Days
Loading…
Total Days
Loading…
Total Cost
Loading…

## Daily Activity

### —

Less
More
Loading…

#### Month Stats

Top Model (Cost)
—
Total Tokens
0
Total Cost
$0.00
Messages
0
Active Days
0
Streak
0 days

### —

Less
More
Loading…
Cost (USD)
Less
More
Totals
Cost
$0
Tokens
0
Most Active Day
Date
—
Tokens
—
Cost
—
💡 Click any cube to view day details

### Day Details

### Session

-

Input
-
-
Cache Read
-
-
Output
-
-
Total Tokens
-
-

#### Token Share

Total
Input -
Cache Read -
Output -
Reasoning -

#### Turn Trend

Tokens

#### Cumulative Turn Trend

Tokens

#### Cumulative Trend by Time

Tokens